if [ -z ${CONDA_BUILD+x} ]; then
    source /opt/concourse/worker/volumes/live/a37ae645-1b0c-4e74-6e27-129b584ab47c/volume/pymongo_1613849775885/work/build_env_setup.sh
fi
python setup.py install --single-version-externally-managed --record=record.txt